==> nateon-1.0.1.275.tar.bz2: nateon-1.0/nateon/dialog/addfriendview.h <==
/***************************************************************************
 *   Copyright (C) 2008 by SK Communications.                              *
 *   http://kldp.net/projects/nateon/                                      *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 3 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/

#ifndef ADDFRIENDVIEW_H
#define ADDFRIENDVIEW_H

#include <kmessagebox.h>
#include <qlineedit.h>
#include <qtextedit.h>
#include <qpushbutton.h>
#include <qcombobox.h>

#include "addfriendinterface.h"

class QLineEdit;
class QTextEdit;
class QPushButthon;
class QComboBox;

/**
   @author Doo-Hyun Jang <ring0320@nate.com>
*/
class AddFriendView : public AddFriendForm {
    Q_OBJECT
public:
    AddFriendView(QWidget *parent = 0, const char *name = 0);

    ~AddFriendView();

    void initalize();
    void clear();
    QString getID() {
        return lineeditID->text();
    };
    QString getDomain() {
        return comboBox1->currentText();
    };
    QString getMessage() {
        return texteditMessage->text();
    };

private slots:
    void slotRequire();
    void slotTextCheck();
    void slotCancel();

signals:
    void addFriendRequire( AddFriendView* );
};

#endif

==> nateon-1.0-20071114.tar.bz2: nateon-1.0/nateon/dialog/addfriendview.h <==
/***************************************************************************
 *   Copyright (C) 2007 by Doo-Hyun Jang                                   *
 *   ring0320@nate.com                                                     *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/
#ifndef ADDFRIENDVIEW_H
#define ADDFRIENDVIEW_H

#include <kmessagebox.h>
#include <qlineedit.h>
#include <qtextedit.h>
#include <qpushbutton.h>
#include <qcombobox.h>

#include "addfriendinterface.h"

class QLineEdit;
class QTextEdit;
class QPushButthon;
class QComboBox;

/**
   @author Doo-Hyun Jang <ring0320@nate.com>
*/
class AddFriendView : public AddFriendForm
{
Q_OBJECT
public:
    AddFriendView(QWidget *parent = 0, const char *name = 0);

    ~AddFriendView();

    void initalize();
    void clear();
    QString getID() { return lineeditID->text(); };
    QString getDomain() { return comboBox1->currentText(); };
    QString getMessage() { return texteditMessage->text(); };

private slots:
	void slotRequire();
	void slotNotFound();
	void slotTextCheck();
	// void slotCancel();

signals:
	void addFriendRequire( AddFriendView* );
};

#endif
